@@ -83,7 +83,6 @@ def track(targets):
 
             id = target["id"]
             name = target["name"]
-            parameters = target["parameters"]
 
             if id in output["targets"]:
                 target = output["targets"][id]
@@ -103,7 +102,10 @@ def track(targets):
 
                 print(termcolor.colored(f"{'-' * len(title)}", "cyan"))
                 try:
-                    main(**parameters)
+                    if "parameters" in target:
+                        main(**target["parameters"])
+                    else:
+                        main()
                 except:
                     print(traceback.format_exc(), end="")
                     target["working"] = False
